var searchData=
[
  ['nfc_5fcmd_5fbase_5faddr_0',['NFC_CMD_BASE_ADDR',['../atsam_2include_2libchip_2include_2smc_8h.html#a46f5cb731363fac8581ab25668eb3f46',1,'smc.h']]],
  ['nfc_5fsram_5fbase_5faddress_1',['NFC_SRAM_BASE_ADDRESS',['../atsam_2include_2libchip_2include_2smc_8h.html#a5afb3d057e1f68dfa2641b220f49f03b',1,'smc.h']]],
  ['nop_2',['nop',['../sparc_8h.html#a6c92c29fa8e83ab85e05543010e10d7c',1,'sparc.h']]]
];
